@@ -12,19 +12,9 @@ from pandas_visual_analysis.widgets import WidgetClassRegistry
 
 
 class VisualAnalysis:
-    """
-    Generate linked plots that support brushing from a pandas.DataFrame and display them in Jupyter notebooks.
 
-    :param data: the pandas.DataFrame object or a :class:`DataSource`
-    :param layout: layout specification name or explicit definition of plot in rows
-    :param categorical_columns: if given, specifies which columns are to be interpreted as categorical
-    :param row_height: height in pixels each row and consequently each plot should have
-    :param sample: int or float specifying if the DataFrame should be sub-sampled.
-        When an int is given, the DataFrame will be limited to that number of rows given by the value.
-        When a float is given, the DataFrame will include the fraction of rows given by the value.
-    :param select_color: RGB tuple or hex color specifying the color display selected data points
-    :param deselect_color: RGB tuple or hex color specifying the color display deselected data points
-    :param alpha: opacity of data points
+    """
+    Generate plots that support linked-brushing from a pandas `DataFrame` and display them in Jupyter notebooks.
     """
 
     def __init__(
@@ -32,12 +22,44 @@ class VisualAnalysis:
         data: typing.Union[DataFrame, DataSource],
         layout: typing.Union[str, typing.List[typing.List[str]]] = "default",
         categorical_columns: typing.Union[typing.List[str], None] = None,
-        row_height: int = 400,
+        row_height: typing.Union[int, typing.List[int]] = 400,
         sample: typing.Union[float, int, None] = None,
         select_color: typing.Union[str, typing.Tuple[int, int, int]] = "#323EEC",
         deselect_color: typing.Union[str, typing.Tuple[int, int, int]] = "#8A8C93",
         alpha: float = 0.75,
+        seed: typing.Union[int, None] = None,
     ):
+        """
+
+        :param data: A pandas.DataFrame object or a :class:`DataSource`.
+        :param layout: Layout specification name or explicit definition of widget names in rows.
+            Those columns have to include all columns of the DataFrame
+            which have type `object`, `str`, `bool` or `category`.
+            This means it can only add columns which do not have the aforementioned types.
+            Defaults to 'default'.
+        :param categorical_columns: If given, specifies which columns are to be interpreted as categorical.
+            Defaults to None.
+        :param row_height: Height in pixels each row should have. If given an integer, each row has the height
+            specified by that value, if given a list of integers, each value in the list specifies the height of
+            the corresponding row.
+            Defaults to 400.
+        :param sample: Int or float value specifying if the DataFrame should be sub-sampled.
+            When an int is given, the DataFrame will be limited to that number of rows given by the value.
+            When a float is given, the DataFrame will include the fraction of rows given by the value.
+            Defaults to None.
+        :param select_color: RGB tuple or hex color specifying the color display selected data points.
+            Values in the tuple have to be between 0 and 255 inclusive or a hex string that converts to
+            such RGB values.
+            Defaults to '#323EEC'.
+        :param deselect_color: RGB tuple or hex color specifying the color display deselected data points.
+            Values in the tuple have to be between 0 and 255 inclusive or a hex string that converts to
+            such RGB values.
+            Defaults to '#8A8C93'.
+        :param alpha: Opacity of data points when applicable ranging from 0.0 to 1.0 inclusive. Defaults to 0.75.
+        :param seed: Random seed used for sampling the data.
+            Values can be any integer between 0 and 2**32 - 1 inclusive or None.
+            Defaults to None.
+        """
         super().__init__()
 
         validate.validate_data(data)
@@ -71,7 +93,10 @@ class VisualAnalysis:
 
         if isinstance(data, DataFrame):
             self.data_source = DataSource(
-                df=data, categorical_columns=categorical_columns, sample=sample
+                df=data,
+                categorical_columns=categorical_columns,
+                sample=sample,
+                seed=seed,
             )
         elif isinstance(data, DataSource):
             self.data_source = data
@@ -95,6 +120,11 @@ class VisualAnalysis:
             )
 
     def _ipython_display_(self):
+        """
+        Builds the layout and calls :func:`IPython.core.display.display`
+
+        :return:
+        """
         from IPython.core.display import display
         from ipywidgets import widgets
 
@@ -103,6 +133,11 @@ class VisualAnalysis:
         display(root_widget)
 
     def _check_numerical_plots(self) -> typing.List[str]:
+        """
+        Checks if the layout contains widgets that can only display numerical data.
+
+        :return: Set of widgets in the layout that are strictly numerical. Empty set otherwise.
+        """
         numerical_plots = {"ParallelCoordinates"}
         found_plots = set()
         for row in self.layout.layout_spec:
@@ -112,6 +147,11 @@ class VisualAnalysis:
         return list(found_plots)
 
     def _check_categorical_plots(self) -> typing.List[str]:
+        """
+        Checks if the layout contains widgets that can only display categorical data.
+
+        :return: Set of widgets in the layout that are strictly categorical. Empty set otherwise.
+        """
         numerical_plots = {"ParallelCategories"}
         found_plots = set()
         for row in self.layout.layout_spec:
@@ -122,4 +162,8 @@ class VisualAnalysis:
 
     @staticmethod
     def widgets():
+        """
+
+        :return: All the widget names that are available as input to a layout.
+        """
         return WidgetClassRegistry().widget_list
